@@ -173,76 +173,6 @@ QDateTime Contact::updated() const
     return d->updated;
 }
 
-void Contact::setSpousesName(const QString &name)
-{
-    insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-SpousesName"), name);
-}
-
-QString Contact::spousesName() const
-{
-    return custom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-SpousesName"));
-}
-
-void Contact::setManagersName(const QString &name)
-{
-    insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-ManagersName"), name);
-}
-
-QString Contact::managersName() const
-{
-    return custom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-ManagersName"));
-}
-
-void Contact::setAssistantsName(const QString &name)
-{
-    insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-AssistantsName"), name);
-}
-
-QString Contact::assistantsName() const
-{
-    return custom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-AssistantsName"));
-}
-
-void Contact::setProfession(const QString &profession)
-{
-    insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-Profession"), profession);
-}
-
-QString Contact::profession() const
-{
-    return custom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-Profession"));
-}
-
-void Contact::setOffice(const QString &office)
-{
-    insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-Office"), office);
-}
-
-QString Contact::office() const
-{
-    return custom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-Office"));
-}
-
-void Contact::setAnniversary(const QString &anniversary)
-{
-    insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-Anniversary"), anniversary);
-}
-
-QString Contact::anniversary() const
-{
-    return custom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-Anniversary"));
-}
-
-void Contact::setBlogFeed(const QString &url)
-{
-    insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("BlogFeed"), url);
-}
-
-QString Contact::blogFeed() const
-{
-    return custom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("BlogFeed"));
-}
-
 void Contact::addGroup(const QString &group)
 {
     if (d->groups.contains(group))
