@@ -15,7 +15,7 @@
     GNU Lesser General Public License for more details.
 
     You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    License along with this library.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #ifndef LIBKGAPI2_DRIVE_CHANGE_H
@@ -49,7 +49,9 @@ class KGAPIDRIVE_EXPORT Change: public KGAPI2::Object
   public:
     explicit Change();
     explicit Change(const Change& other);
-    virtual ~Change();
+    ~Change() override;
+    bool operator==(const Change &other) const;
+    bool operator!=(const Change &other) const { return !operator==(other); }
 
     /**
      * @brief Returns the id of the change.
